@@ -7,8 +7,8 @@ from PIL import Image
 global img,original_img,img_path,Scale
 global point1,point2,devices
 
-def screen_shot(devices,save_img_path):
-    global img_path
+def screen_shot(save_img_path):
+    global img_path,devices
     img_path=save_img_path
     u=devices
     screen_image = 'image' + str(random.randint(1, 1000000)) + '.png'
@@ -30,14 +30,14 @@ def on_mouse(event, x, y, flags, param):
     img2 = img.copy()
     if event == cv2.EVENT_LBUTTONDOWN: #左键点击
         point1 = (x,y)
-        cv2.circle(img2, point1, 10, (0,255,0), 2)
+        cv2.circle(img2, point1, 10, (255,0,0), 2)
         cv2.imshow('image', img2)
     elif event == cv2.EVENT_MOUSEMOVE and (flags & cv2.EVENT_FLAG_LBUTTON): #按住左键拖曳
-        cv2.rectangle(img2, point1, (x,y), (200,0,0), 2)
+        cv2.rectangle(img2, point1, (x,y), (255,0,0), 2)
         cv2.imshow('image', img2)
     elif event == cv2.EVENT_LBUTTONUP: #左键释放
         point2 = (x,y)
-        cv2.rectangle(img2, point1, point2, (0,0,255), 2)
+        cv2.rectangle(img2, point1, point2, (255,0,0), 2)
         cv2.imshow('image', img2)
         a = int(point1[0]) / Scale
         b = int(point2[0]) / Scale
@@ -73,10 +73,10 @@ def crop():
     cv2.waitKey(0)
 
 
-def get_image(devices,save_img_path,scale):
+def get_image(save_img_path,scale):
     global Scale
     Scale=float(scale)
-    screen_shot(devices,save_img_path)
+    screen_shot(save_img_path)
     crop()
 
 def element_click(devices,Prop,Value):
@@ -134,9 +134,9 @@ def devices_connect(device_type,devices):
 
 
 
-# devices=devices_connect('android',None)
+devices=devices_connect('android',None)
 # save_img_path='F:/'
-# get_image(devices,save_img_path,0.5)
+# get_image(save_img_path,0.5)
 
 
 
